//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

  WSGIappLocaleSet()->setLocaleString("zh_CN","","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","B4:WSSTR Confirmation","ѯ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","C4:WSSTR ObjectBox","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","D4:WSSTR ProjectSettings","Ŀ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","E4:WSSTR New project","½Ŀ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","F4:WSSTR Open project","Ŀ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","G4:WSSTR Save project","Ŀ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","H4:WSSTR Close project","رĿ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","I4:WSSTR New application window","½");
  WSGIappLocaleSet()->setLocaleString("zh_CN","J4:WSSTR Open application window","򿪴");
  WSGIappLocaleSet()->setLocaleString("zh_CN","K4:WSSTR Save application window","洰");
  WSGIappLocaleSet()->setLocaleString("zh_CN","L4:WSSTR Delete instance","ɾ/");
  WSGIappLocaleSet()->setLocaleString("zh_CN","M4:WSSTR Properties","༭");
  WSGIappLocaleSet()->setLocaleString("zh_CN","N4:WSSTR Procedures","ô");
  WSGIappLocaleSet()->setLocaleString("zh_CN","O4:WSSTR Display the object box","ʾ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","P4:WSSTR Project settings","Ŀ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Q4:WSSTR Build all","ȫ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Q4:WSSTR Cancel","ȡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","R4:WSSTR Execute","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","S4:WSSTR Find instances","/ʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","T4:WSSTR Find files","ļ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","U4:WSSTR Help","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","V4:WSSTR  File(F)"," ļ(F)");
  WSGIappLocaleSet()->setLocaleString("zh_CN","W4:WSSTR New window(N)         :m11:N,Open window(O):m12:O,Save window(S):m13:S,Save as(R):m14:R,Save all(A):m15:A,SP,Exit(X):m16:X","½(N)      :m11:N:0:$(WSDIR)/sys/pixmaps/wcreate.png,򿪴(O):m12:O:0:$(WSDIR)/sys/pixmaps/wload.png,洰(S):m13:S:0:$(WSDIR)/sys/pixmaps/wsave.png,Ϊ(R):m14:R,ȫ(A):m15:A,SP,˳(X):m16:X:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("zh_CN","X4:WSSTR  Edit(E)"," ༭(E)");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Y4:WSSTR Copy(C):m21:C,Paste(P):m22:P,SP,Display(I):m27:I,Find(F):m28:F,Delete(D):m23:D,SP,Properties(R):m24:R,Procedures:{List up(L):m25:L,New procedure(N):m251:N,Properties(S):m252:S,Edit(E):m253:E,Delete(X):m254:X},Attributes(A):m26:A,Files(L):m29:L","ȡ(U):m291:U:1,(C):m21:C,ճ(P):m22:P,SP,ʾ(I):m27:I,ʵ(F):m28:F,ɾ(D):m23:D,SP,Ա༭(R):m24:R,̱༭:{һ(L):m25:L,½(N):m251:N,(S):m252:S,༭(E):m253:E,ɾ(X):m254:X},(A):m26:A,ļһ(L):m29:L");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Z4:WSSTR  Build(B)"," (B)");
  WSGIappLocaleSet()->setLocaleString("zh_CN","a4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Execute(X):m36:X,Execute with Trace(T):m39:T,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","(C)    :m31:C,ȫ(B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,(R):m33:R,(E):m34:E,SP,(D):m35:D,(X):m36:X:0:$(WSDIR)/sys/pixmaps/run.png,(T):m39:T,SP,Դ(G):m37:G,Ϣ(I):m38:I");
  WSGIappLocaleSet()->setLocaleString("zh_CN","b4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Abort(X):m36:X,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","(C)    :m31:C,ȫ(B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,(R):m33:R,(E):m34:E,SP,(D):m35:D,ֹͣ(X):m36:X:0:$(WSDIR)/sys/pixmaps/runx.png,SP,Դ(G):m37:G,Ϣ(I):m38:I");
  WSGIappLocaleSet()->setLocaleString("zh_CN","c4:WSSTR  View(V)"," ʾ(V)");
  WSGIappLocaleSet()->setLocaleString("zh_CN","d4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Terminal(T):m45:T","ļ(D) :m46:D,(I) :m47:I,ʵ༭(E) :m48:E,Ӵ(L) :m49:L,(O)     :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,(C):m42:C,(B):m43:B,SP,ն(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("zh_CN","e4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Find Files(F):m44:F,Terminal(T):m45:T","ļ(D) :m46:D,(I) :m47:I,ʵ༭(E) :m48:E,Ӵ(L) :m49:L,(O)     :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,(C):m42:C,(B):m43:B,SP,ļ(F):m44:F,ն(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("zh_CN","f4:WSSTR  Project(P)"," Ŀ(P)");
  WSGIappLocaleSet()->setLocaleString("zh_CN","g4:WSSTR New project(N)        :m51:N,Open project(O):m52:O,Save project(S):m53:S,Rename project(R):m54:R,SP,Project settings(E):m55:E,SP,Close project(C):m56:C","½Ŀ(N)      :m51:N:0:$(WSDIR)/sys/pixmaps/pcreate.png,Ŀ(O) :m52:O:0:$(WSDIR)/sys/pixmaps/pload.png,Ŀ(S):m53:S:0:$(WSDIR)/sys/pixmaps/psave.png,ĿΪ(R):m54:R,SP,Ŀ(E):m55:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP,رĿ(C):m56:C:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("zh_CN","h4:WSSTR  Option(O)"," ѡ(O)");
  WSGIappLocaleSet()->setLocaleString("zh_CN","i4:WSSTR Environment(E)    :m61:E,SP,Colors(C):m62:C,Fonts(F):m63:F,Look and Feel(L):m64:L","(E)      :m61:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP,ɫ(C):m62:C,(F):m63:F,(L):m64:L");
  WSGIappLocaleSet()->setLocaleString("zh_CN","j4:WSSTR  Help(H)"," (H)");
  WSGIappLocaleSet()->setLocaleString("zh_CN","k4:WSSTR Index(I):m81:I,Reference(R)     :m82:R,User's guide(U):m83:U,About WideStudio(V):m84:V,License(L):m85:L","Ŀ¼(I):m81:I:0:$(WSDIR)/sys/pixmaps/help.png,ο(R)     :m82:R,ʹ÷(U):m83:U,汾Ϣ(V):m84:V,֤Ϣ(L):m85:L");
  WSGIappLocaleSet()->setLocaleString("zh_CN","l4:WSSTR Please specify a window to save.","ѡҪĴڡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","m4:WSSTR Continue saving?","ȷϱ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","n4:WSSTR Please specify some instances to copy.","ѡҪƵʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","o4:WSSTR Please specify a instance to paste.","ѡҪճʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","p4:WSSTR Some instances are selected to paste.\nPlease specify a instance.","ֻѡһҪճʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","q4:WSSTR Please select the instance to delete.","ѡҪɾʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","r4:WSSTR Delete instance: ","ȷɾ ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","s4:WSSTR  ?"," ʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","t4:WSSTR Please specify a instance to display.","ѡҪʾʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","u4:WSSTR There is no instance for search.","󲻴ڡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","v4:WSSTR Please specify a application window to compile.","ѡĴڡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","w4:WSSTR Please check the debugger settings or confirm whether the project is built.","ȷϵǷȷĿǷɡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","x4:WSSTR Can not execute the class library...","⡣");
  WSGIappLocaleSet()->setLocaleString("zh_CN","y4:WSSTR Can not execute the load module.\nPlease confirm whether the project is collect or built.","ģ顣\nȷĿǷȷĿǷɡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","z4:WSSTR Please specify a application window to generate source code.","ѡҪɵĴڡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","A4:WSSTR Please wait for a while to start web browser..","ڴ򿪰Ժ...");
  WSGIappLocaleSet()->setLocaleString("zh_CN","B4:WSSTR NoName","ޱ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","C4:WSSTR Unexpected error occurred in reading the project files...","Ŀļʱ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","D4:WSSTR Can not open File: ","ļ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","E4:WSSTR  .","\nʱ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","F4:WSSTR Can not save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","G4:WSSTR  .","ʧܡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","H4:WSSTR The project was modified.\nSave it?","Ŀѱ޸ġ\nȷϱ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","I4:WSSTR Abort saving the application window.","ڱ汻жϡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","J4:WSSTR Some application windows were modified \nSave them?","ѱ޸ġ\nȷϱ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","K4:WSSTR The project has no name.\nName the project and save it?","Ŀδ\nȷָƱ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","L4:WSSTR Exit the application builder?","ȷֹ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","M4:WSSTR Sorry, under construction...","...");
  WSGIappLocaleSet()->setLocaleString("zh_CN","N4:WSSTR Failed to save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","O4:WSSTR Do you continue?","ʧܣ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","P4:WSSTR \",\n","\",\n");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Q4:WSSTR No project is specified.\nGenerate a new project?","δָĿ\nĿ½Ŀ\nȷ½Ŀ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","R4:WSSTR Please specify a keyword to search files.","ָؼ֡");
  WSGIappLocaleSet()->setLocaleString("zh_CN","S4:WSSTR No editor is specified.\nPlease confirm the project settings and specify the editor.","δָ༭\nĿָ༭");
  WSGIappLocaleSet()->setLocaleString("zh_CN","S4:WSSTR No editor option is specified.\nPlease confirm the project settings and specify the editor.","δָ༭ѡ\nĿָ༭ѡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","T4:WSSTR New project","½Ŀ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","U4:WSSTR < Back,Next >,Finish","< ,һ >,");
  WSGIappLocaleSet()->setLocaleString("zh_CN","V4:WSSTR Project name","Ŀ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","W4:WSSTR Working dir","Ŀ¼");
  WSGIappLocaleSet()->setLocaleString("zh_CN","X4:WSSTR Project type","Ŀ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Y4:WSSTR  Normal application"," ͨӦó");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Z4:WSSTR  Class library component"," ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","W4:WSSTR New application window","½");
  WSGIappLocaleSet()->setLocaleString("zh_CN","X4:WSSTR < Back,Next >,Finish","< ,һ >,");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Y4:WSSTR Type","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Z4:WSSTR  Normal window"," ͨ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","a4:WSSTR  Class"," ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","b4:WSSTR Project","ע");
  WSGIappLocaleSet()->setLocaleString("zh_CN","c4:WSSTR  Add to project"," עᵽĿ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","d4:WSSTR Name","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","e4:WSSTR Please specify a instance name to search.","ָʵƣ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","f4:WSSTR Please specify a value of the property to search instance.","ֵָ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","f4:WSSTR Please specify a property name likes [WSN...] to search instance.","ָ WSN... ͷơ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","g4:WSSTR Please specify search condition.","ָ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","h4:WSSTR No instance.","ûзָʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","i4:WSSTR Find instances","ʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","j4:WSSTR Find","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","k4:WSSTR Instance name,Properties,Procedures","ʵ,,");
  WSGIappLocaleSet()->setLocaleString("zh_CN","l4:WSSTR InstanceName","ʵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","m4:WSSTR Comparison","ʽ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","n4:WSSTR  Complete equal","ȫƥ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","o4:WSSTR PropertyName","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","p4:WSSTR Value","ֵ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","q4:WSSTR ProcedureName","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","r4:WSSTR FunctionName","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","s4:WSSTR Direction","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","t4:WSSTR  Downward"," ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","u4:WSSTR  Upward"," ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","v4:WSSTR Find files","ļ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","w4:WSSTR < Back,Find, Find","< ,, ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","x4:WSSTR Dir:","λ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","y4:WSSTR File type:","ļ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","z4:WSSTR Keyword:","ؼ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","A4:WSSTR Failed to save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","B4:WSSTR .","\nʧܡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","C4:WSSTR Delete instance:","ʵ:");
  WSGIappLocaleSet()->setLocaleString("zh_CN","D4:WSSTR ?","\nȷɾ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","E4:WSSTR Add application window: ",": ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","F4:WSSTR  to the project?"," ȷעᵽĿ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","G4:WSSTR Remove application window: ",": ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","H4:WSSTR  from the project?"," ȷϴĿɾ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","I4:WSSTR Failed to read file:","ļ: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","J4:WSSTR .\nDo you stop reading?","\nʱ\nȷֹļ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","K4:WSSTR Failed to open File: ","ļ: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","L4:WSSTR .","\nܱ򿪡");
  WSGIappLocaleSet()->setLocaleString("zh_CN","M4:WSSTR Failed to write File: ","ļ: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","N4:WSSTR .","\nд");
  WSGIappLocaleSet()->setLocaleString("zh_CN","O4:WSSTR Invalid name: ","Ч: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","P4:WSSTR .\nPlease specify a usable name in C/C++ variables.","\n ָC/C++ʹõıơ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","P4:WSSTR .\nAlready used by project name.",".\nĿѾڣָơ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","P4:WSSTR .\nCan not use array name.",".\nָΪ");

  WSGIappLocaleSet()->setLocaleString("zh_CN","Q4:WSSTR Can not generate the specified class: ","ָ: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","R4:WSSTR ."," ɡ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","S4:WSSTR Can not change the specified class: ","ָ: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","T4:WSSTR  to window type.\nPlease specify a class of window/dialog base."," תΪ͡\nָࡣ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","U4:WSSTR Can not paste the instance on the specified instance: ","ʵ: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","V4:WSSTR ."," \nܱճָʵС");
  WSGIappLocaleSet()->setLocaleString("zh_CN","W4:WSSTR Can not paste the specified instance: ","ʵ: ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","X4:WSSTR ,\nbecause it overlap the source and the destination...","ظơ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Y4:WSSTR Locale type","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Y4:WSSTR Language","");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Y4:WSSTR Templates","ģ");
  WSGIappLocaleSet()->setLocaleString("zh_CN","Z4:WSSTR Can not read file:","ļ:");
  WSGIappLocaleSet()->setLocaleString("zh_CN","a4:WSSTR .","\n ܱ򿪡$ȷ(WSDIR) á");
  WSGIappLocaleSet()->setLocaleString("zh_CN","a4:WSSTR Look and Feel","");
